@@ -10,8 +10,10 @@
 
 namespace Dasher {
   class CDasherInput;
+  class CDasherInterfaceBase;
 }
-
+/// \defgroup Input Input devices
+/// \{
 class Dasher::CDasherInput : public CDasherModule {
 
 public:
@@ -39,6 +41,14 @@ public:
   /// Deactivate the device. Please don't hold on to any significant
   /// resources (eg helper threads) after deactivation.
   virtual void Deactivate() {};
-};
 
+  /// Handle key down events
+  ///
+  virtual void KeyDown(int iTime, int iId) {};
+
+  ///
+  /// Handle key up events
+  virtual void KeyUp(int iTime, int iId) {};
+};
+/// \}
 #endif
