@@ -2,8 +2,6 @@
 //
 // Copyright (c) 2001-2004 David Ward
 
-// TODO - there's no real reason to distinguish between groups and nodes here - they're all just boxes to be rendered, with the distinction being at the level of the alphabet manager
-
 #include "../Common/Common.h"
 
 #ifdef _WIN32
@@ -131,6 +129,8 @@ void CDasherViewSquare::RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iR
 
 int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2, int mostleft, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, myint *iGamePointer, bool bDraw,myint parent_width,int parent_color) {
 
+  //  std::cout << "Recursive render: " << pRender << " " << y1 << " " << y2 << std::endl;
+
   DASHER_ASSERT_VALIDPTR_RW(pRender);
 
   // TODO: We need an overhall of the node creation/deletion logic - make sure that we only maintain the minimum number of nodes which are actually needed.
@@ -139,34 +139,21 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
 
   ++m_iRenderCount;
  
-  SGroupInfo *group=pRender->m_pBaseGroup;
   myint temp_parentwidth=parent_width;
-  myint trange = y2 - y1;
+  //  myint trange = y2 - y1;
   int temp_parentcolor=parent_color;
-  //Ignas. Group rendering is not finished. 
-/*  if (group!=NULL)
-	{
 
-		myint lbnd = pRender->Children()[group->iStart]->Lbnd();
-		myint hbnd = pRender->Children()[group->iEnd - 1]->Hbnd();
-		myint tnewy1 = y1 + (trange * lbnd) / (int)GetLongParameter(LP_NORMALIZATION);
-		myint tnewy2 = y1 + (trange * hbnd) / (int)GetLongParameter(LP_NORMALIZATION);
-		temp_parentwidth=tnewy2-tnewy1;
-		temp_parentcolor=group->iColour;
-			
-	}
-		
-  */
+  // TODO: Pass displayinfo directly here
   if(bDraw && 
-	  !RenderNodeFatherFast(parent_color, y1, y2, mostleft, pRender->m_strDisplayText, pRender->GetShove(),parent_width) 
-	    && !(pRender->GetFlag(NF_GAME))) {
+     !RenderNodeFatherFast(parent_color, y1, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,parent_width, pRender->GetDisplayInfo()->bVisible) &&
+     !(pRender->GetFlag(NF_GAME))) {
     vDeleteList.push_back(pRender);
     pRender->SetFlag(NF_ALIVE, false);
     return 0;
   }
   
   if(pRender->ChildCount() == 0) {
-	  RenderNodePartFast(pRender->Colour(), y1, y2, mostleft, pRender->m_strDisplayText, pRender->GetShove(),y2-y1);
+	  RenderNodePartFast(pRender->GetDisplayInfo()->iColour, y1, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,y2-y1);
     vNodeList.push_back(pRender);
     return 1;  // CHANGED BY IGNAS. I return 1 when the child was rendered and in this case the 
 			   //child was rendered.
@@ -175,9 +162,6 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
   if(pRender->GetFlag(NF_GAME))
     *iGamePointer = (y1 + y2) / 2;
   
-  // Ignas. Group rendering is not implemented yet.
-//  RenderGroupsFast(pRender, y1, y2, mostleft);
-
   // Render children  
   int norm = (myint)GetLongParameter(LP_NORMALIZATION);
 
@@ -200,9 +184,13 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
   
   
   int id=-1;
-  int lower=-1,upper=-1;
+  //  int lower=-1,upper=-1;
   temp_parentwidth=y2-y1;
-  temp_parentcolor=pRender->Colour();
+  if(pRender->GetDisplayInfo()->bVisible)
+    temp_parentcolor=pRender->GetDisplayInfo()->iColour;
+  else
+    temp_parentcolor=parent_color;
+    
   for(i = pRender->GetChildren().begin(); i != pRender->GetChildren().end(); i++) {
     id++;
     CDasherNode *pChild = *i;
@@ -210,35 +198,6 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
     myint Range = y2 - y1;
     myint newy1 = y1 + (Range * (myint)pChild->Lbnd()) / (myint)norm;/// norm and lbnd are simple ints
     myint newy2 = y1 + (Range * (myint)pChild->Hbnd()) / (myint)norm;
-    
-/*   IGNAS. Group rendering is not finished yet.
-   if (group!=NULL)
-	{	
-		lower=group->iStart;
-		upper=group->iEnd;
-		if(lower-1==id)
-		{
-			if (lasty<newy1)
-			{
-				RenderNodePartFast(pRender->Colour(), lasty, newy1, mostleft, pRender->m_strDisplayText, pRender->GetShove(),y2-y1,test1);
-				lasty=newy1;
-			}
-
-			myint lbnd = pRender->Children()[lower]->Lbnd();
-			myint hbnd = pRender->Children()[upper - 1]->Hbnd();
-			myint tnewy1 = y1 + (trange * lbnd) / (int)GetLongParameter(LP_NORMALIZATION);
-			myint tnewy2 = y1 + (trange * hbnd) / (int)GetLongParameter(LP_NORMALIZATION);
-			temp_parentwidth=tnewy2-tnewy1;
-			temp_parentcolor=group->iColour;
-			
-		}
-	
-	}
-	else
-	{
-		temp_parentwidth=parent_width;
-		temp_parentcolor=parent_color;
-	}*/
 
     // FIXME - make the threshold a parameter
     
@@ -248,7 +207,7 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
 	  {
 		  if ((bDraw)&&(lasty<newy1))   //if child has been drawn then the interval between him and the
 							//last drawn child should be drawn too.
-		  RenderNodePartFast(temp_parentcolor, lasty, newy1, mostleft, pRender->m_strDisplayText, pRender->GetShove(),temp_parentwidth);
+		  RenderNodePartFast(temp_parentcolor, lasty, newy1, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,temp_parentwidth);
 		  lasty=newy2;
 	  }
 	  
@@ -259,76 +218,25 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
 		{
 			if ((bDraw)&&(lasty<newy1))   //if child has been drawn then the interval between him and the
 							  //last drawn child should be drawn too.
-			  RenderNodePartFast(temp_parentcolor, lasty, newy1, mostleft, pRender->m_strDisplayText, pRender->GetShove(),temp_parentwidth);
+			  RenderNodePartFast(temp_parentcolor, lasty, newy1, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,temp_parentwidth);
 			lasty=newy2;
 		}
 	
     }
-/*  //IGNAS. Group rendering is not finished yet.
-    if (group!=NULL)
-	{
-		if (upper-1==id)
-			{
-				group=group->pNext;
-				temp_parentwidth=parent_width;
-				temp_parentcolor=parent_color;
-
-				RenderNodePartFast(temp_parentcolor, lasty, newy1, mostleft, pRender->m_strDisplayText, pRender->GetShove(),temp_parentwidth,test1);
-				lasty=newy2;
-
-
-			}
-	}
-*/	
   
   }
   if (bDraw)
   {
 		if (lasty<y2)
-			  RenderNodePartFast(temp_parentcolor, lasty, y2, mostleft, pRender->m_strDisplayText, pRender->GetShove(),temp_parentwidth);
+			  RenderNodePartFast(temp_parentcolor, lasty, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,temp_parentwidth);
   
-		RenderNodeOutlineFast(pRender->Colour(), y1, y2, mostleft, pRender->m_strDisplayText, pRender->GetShove());
+		RenderNodeOutlineFast(pRender->GetDisplayInfo()->iColour, y1, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove);
   }
 
   return 1;
 }
 
 
-void CDasherViewSquare::RenderGroupsFast(CDasherNode *Render, myint y1, myint y2, int mostleft) {
-  SGroupInfo *pCurrentGroup(Render->m_pBaseGroup);
-
-  while(pCurrentGroup) {
-	  RecursiveRenderGroupsFast(pCurrentGroup, Render, y1, y2, mostleft,Render->Colour());
-    pCurrentGroup = pCurrentGroup->pNext;
-  }
-}
-//NOT finished
-void CDasherViewSquare::RecursiveRenderGroupsFast(SGroupInfo *pCurrentGroup, CDasherNode *pNode, myint y1, myint y2, int mostleft,int iParentColor) {
-  
-  if(pCurrentGroup->bVisible) {
-    myint range = y2 - y1;
-    
-    int lower(pCurrentGroup->iStart);
-    int upper(pCurrentGroup->iEnd);
-    
-    myint lbnd = pNode->Children()[lower]->Lbnd();
-    myint hbnd = pNode->Children()[upper - 1]->Hbnd();
-    
-    myint newy1 = y1 + (range * lbnd) / (int)GetLongParameter(LP_NORMALIZATION);
-    myint newy2 = y1 + (range * hbnd) / (int)GetLongParameter(LP_NORMALIZATION);
-    
-	RenderNodeFatherFast(iParentColor, newy1, newy2, mostleft, pCurrentGroup->strLabel, true,y2-y1);
-    
-  }
-  
-  // Iterate through child groups 
-/*  SGroupInfo *pCurrentChild(pCurrentGroup->pChild);
-
-  while(pCurrentChild) {
-	  RecursiveRenderGroupsFast(pCurrentChild, pNode, y1, y2, mostleft,pCurrentGroup->iColour);
-    pCurrentChild = pCurrentChild->pNext;
-  }*/
-}
 
 
 CDasherViewSquare::Cymap::Cymap(myint iScale) {
@@ -391,15 +299,20 @@ int CDasherViewSquare::RenderNodeOutlineFast(const int Color, myint y1, myint y2
   // FIXME - get rid of pointless assignment below
 
   int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times 100;
-  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+  //  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
 
   if(iTruncation == 0) {        // Regular squares
-    	  DasherDrawRectangle(std::min(iDasherSize,iDasherMaxX), std::min(y2,iDasherMaxY),0, std::max(y1,iDasherMinY), Color, -1, Nodes1, true,false, 1);
+    DasherDrawRectangle(std::min(iDasherSize,iDasherMaxX), std::min(y2,iDasherMaxY),0, std::max(y1,iDasherMinY), Color, -1, Nodes1, true,false, 1);
+  }
+  else { 
+    // TODO: Put something back here?
   }
-  else { }
 
   return 1;
 }
+
+
+// TODO: Document these functions
 int CDasherViewSquare::RenderNodePartFast(const int Color, myint y1, myint y2, int &mostleft, const std::string &sDisplayText, bool bShove,myint iParentWidth ) {
 
   // Commenting because click mode occasionally fails this assert.
@@ -431,12 +344,12 @@ int CDasherViewSquare::RenderNodePartFast(const int Color, myint y1, myint y2, i
     return 0;                   // We're entirely off screen, so don't render.
   }
 
-  myint iDasherSize(y2 - y1);
+  //  myint iDasherSize(y2 - y1);
 
   // FIXME - get rid of pointless assignment below
 
-  int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times 100;
-  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+  int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times -x100;
+  //  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
 
   if(iTruncation == 0) {        // Regular squares
     DasherDrawRectangle(std::min(iParentWidth,iDasherMaxX), std::min(y2,iDasherMaxY),0, std::max(y1,iDasherMinY), Color, -1, Nodes1, false, true, 1);
@@ -447,7 +360,7 @@ int CDasherViewSquare::RenderNodePartFast(const int Color, myint y1, myint y2, i
   return 1;
 }
 
-int CDasherViewSquare::RenderNodeFatherFast(const int parent_color, myint y1, myint y2, int &mostleft, const std::string &sDisplayText, bool bShove,myint iParentWidth) {
+int CDasherViewSquare::RenderNodeFatherFast(const int parent_color, myint y1, myint y2, int &mostleft, const std::string &sDisplayText, bool bShove,myint iParentWidth, bool bVisible) {
 
   // Commenting because click mode occasionally fails this assert.
   // I don't know why.  -- cjb.
@@ -483,7 +396,7 @@ int CDasherViewSquare::RenderNodeFatherFast(const int parent_color, myint y1, my
   // FIXME - get rid of pointless assignment below
 
   int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times 100;
-  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+  // int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
 
   if(iTruncation == 0) {        // Regular squares
     DasherDrawRectangle(std::min(iParentWidth,iDasherMaxX), std::min(y2,iDasherMaxY), std::min(iDasherSize,iDasherMaxX), std::max(y1,iDasherMinY), parent_color, -1, Nodes1, false, true, 1);
@@ -496,6 +409,7 @@ int CDasherViewSquare::RenderNodeFatherFast(const int parent_color, myint y1, my
   }
   return 1;
 }
+
 int CDasherViewSquare::RenderNode(const int Color, myint y1, myint y2, int &mostleft, const std::string &sDisplayText, bool bShove) {
 
   // Commenting because click mode occasionally fails this assert.
@@ -532,7 +446,7 @@ int CDasherViewSquare::RenderNode(const int Color, myint y1, myint y2, int &most
   // FIXME - get rid of pointless assignment below
 
   int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times 100;
-  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+  //  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
 
   if(iTruncation == 0) {        // Regular squares
     DasherDrawRectangle(std::min(iDasherSize,iDasherMaxX), std::min(y2,iDasherMaxY), 0, std::max(y1,iDasherMinY), Color, -1, Nodes1, GetBoolParameter(BP_OUTLINE_MODE), true, 1);
@@ -838,91 +752,30 @@ void CDasherViewSquare::VisibleRegion( myint &iDasherMinX, myint &iDasherMinY, m
   iDasherMaxY = m_iDasherMaxY;
 }
 
-int CDasherViewSquare::GetCoordinates(unsigned long Time, myint &iDasherX, myint &iDasherY) {
+// void CDasherViewSquare::NewDrawGoTo(myint iDasherMin, myint iDasherMax, bool bActive) {
+//   myint iHeight(iDasherMax - iDasherMin);
 
-  // FIXME - Actually turn autocalibration on and off!
-  // FIXME - AutoCalibrate should use Dasher co-ordinates, not raw mouse co-ordinates?
-  // FIXME - Have I broken this by moving it before the offset is applied?
-  // FIXME - put ymap stuff back in 
-  // FIXME - optimise this
+//   int iColour;
+//   int iWidth;
 
-  int iCoordinateCount(GetCoordinateCount());
+//   if(bActive) {
+//     iColour = 1;
+//     iWidth = 3;
+//   }
+//   else {
+//     iColour = 2;
+//     iWidth = 1;
+//   }
 
-  myint *pCoordinates(new myint[iCoordinateCount]);
+//   CDasherScreen::point p[4];
 
-  int iType(GetInputCoordinates(iCoordinateCount, pCoordinates));
+//   Dasher2Screen( 0, iDasherMin, p[0].x, p[0].y);
+//   Dasher2Screen( iHeight, iDasherMin, p[1].x, p[1].y);
+//   Dasher2Screen( iHeight, iDasherMax, p[2].x, p[2].y);
+//   Dasher2Screen( 0, iDasherMax, p[3].x, p[3].y);
 
-  screenint mousex;
-  screenint mousey;
-
-  if(iCoordinateCount == 1) {
-    mousex = 0;
-    mousey = pCoordinates[0];
-  }
-  else {
-    mousex = pCoordinates[0];
-    mousey = pCoordinates[1];
-  }
-
-  delete[]pCoordinates;
-
-  //  bool autocalibrate = GetBoolParameter(BP_AUTOCALIBRATE);
-  //  if(GetBoolParameter(BP_AUTOCALIBRATE) && (GetStringParameter(SP_INPUT_FILTER) == "Eyetracker Mode")) {
-    //    AutoCalibrate(&mousex, &mousey);
-  //  }
-
-
-  // TODO: Mode probably isn't being used any more
-
-  // Convert the input co-ordinates to dasher co-ordinates
-
-  int mode;
-  
-  mode = 0;
- 
-  //  Input2Dasher(mousex, mousey, iDasherX, iDasherY);
-  Screen2Dasher(mousex, mousey, iDasherX, iDasherY, false, true );
-
-//   m_iDasherXCache = iDasherX;
-//   m_iDasherYCache = iDasherY;
-
-  // Request an update at the calculated co-ordinates
-
-
-  // Cache the Dasher Co-ordinates, so we can use them later for things like drawing the mouse position
-#ifndef WITH_MAEMO
-  // FIXME
-  //  iDasherX = myint(xmap(iDasherX / static_cast < double >(GetLongParameter(LP_MAX_Y))) * GetLongParameter(LP_MAX_Y));
-  // iDasherY = m_ymap.map(iDasherY);
-#endif
-
-  return iType;
-}
-
-void CDasherViewSquare::NewDrawGoTo(myint iDasherMin, myint iDasherMax, bool bActive) {
-  myint iHeight(iDasherMax - iDasherMin);
-
-  int iColour;
-  int iWidth;
-
-  if(bActive) {
-    iColour = 1;
-    iWidth = 3;
-  }
-  else {
-    iColour = 2;
-    iWidth = 1;
-  }
-
-  CDasherScreen::point p[4];
-
-  Dasher2Screen( 0, iDasherMin, p[0].x, p[0].y);
-  Dasher2Screen( iHeight, iDasherMin, p[1].x, p[1].y);
-  Dasher2Screen( iHeight, iDasherMax, p[2].x, p[2].y);
-  Dasher2Screen( 0, iDasherMax, p[3].x, p[3].y);
-
-  Screen()->Polyline(p, 4, iWidth, iColour);
-}
+//   Screen()->Polyline(p, 4, iWidth, iColour);
+// }
 
 void CDasherViewSquare::ChangeScreen(CDasherScreen *NewScreen) {
   CDasherView::ChangeScreen(NewScreen);
