@@ -7,8 +7,8 @@
 
 typedef struct _SCENode SCENode;
 
-
-
+/// \ingroup Model
+/// \{
 struct _SCENode {
 
   char *pszConversion;
@@ -17,11 +17,17 @@ struct _SCENode {
 
   int IsHeadAndCandNum;
   int CandIndex;
+  int Symbol;
+
   int IsComplete;
   int AcCharCount;  /*accumulative character count*/
-  
-};
 
+  int NodeSize;
+
+  uint HZFreq;
+  float HZProb;
+};
+/// \}
 
 #endif
 
